@@ -3,7 +3,7 @@ from typing import Iterable, Union, Mapping
 
 from flask_restful import Resource
 
-from metadata_service.proxy import neo4j_proxy
+from metadata_service.proxy import get_proxy_client
 
 
 class Neo4jDetailAPI(Resource):
@@ -12,10 +12,10 @@ class Neo4jDetailAPI(Resource):
     """
 
     def __init__(self) -> None:
-        self.neo4j = neo4j_proxy.get_neo4j()
+        self.client = get_proxy_client()
 
     def get(self) -> Iterable[Union[Mapping, int, None]]:
-        last_updated_ts = self.neo4j.get_neo4j_latest_updated_ts()
+        last_updated_ts = self.client.get_latest_updated_ts()
         if last_updated_ts is not None:
             return {'neo4j_latest_timestamp': int(last_updated_ts)}, HTTPStatus.OK
         else:
