@@ -1,7 +1,7 @@
 import logging
 import textwrap
 from random import randint
-from typing import Dict, Any, no_type_check, List, Tuple, Union  # noqa: F401
+from typing import Dict, Any, no_type_check, List, Tuple, Union, Optional  # noqa: F401
 
 import time
 from beaker.cache import CacheManager
@@ -607,7 +607,7 @@ class Neo4jProxy(BaseProxy):
         return results
 
     @timer_with_counter
-    def get_latest_updated_ts(self) -> int:
+    def get_latest_updated_ts(self) -> Optional[int]:
         """
         API method to fetch last updated / index timestamp for neo4j, es
 
@@ -620,7 +620,10 @@ class Neo4jProxy(BaseProxy):
                                             param_dict={})
         # None means we don't have record for neo4j, es last updated / index ts
         record = record.single()
-        return record['ts'].get('latest_timestmap')
+        if record:
+            return record.get('ts', {}).get('latest_timestmap', 0)
+        else:
+            return None
 
     @timer_with_counter
     @_CACHE.cache('_get_popular_tables_uris', _GET_POPULAR_TABLE_CACHE_EXPIRY_SEC)
@@ -696,16 +699,18 @@ class Neo4jProxy(BaseProxy):
 
         query = textwrap.dedent("""
         MATCH (user:User {key: $user_id})
-        OPTIONAL MATCH (user)-[:manage_by]->(manager:User)
+        OPTIONAL MATCH (user)-[:MANAGE_BY]->(manager:User)
         RETURN user as user_record, manager as manager_record
         """)
 
         record = self._execute_cypher_query(statement=query,
                                             param_dict={'user_id': user_id})
-        if not record:
+        single_result = record.single()
+
+        if not single_result:
             raise NotFoundException('User {user_id} '
                                     'not found in the graph'.format(user_id=user_id))
-        single_result = record.single()
+
         record = single_result.get('user_record', {})
         manager_record = single_result.get('manager_record', {})
         if manager_record:
@@ -768,8 +773,13 @@ class Neo4jProxy(BaseProxy):
         table_records = record.single().get('table_records', [])
 
         for record in table_records:
-            # todo: decide whether we want to return a list of table entities or just table_uri
-            results.append(self.get_table(table_uri=record['key']))
+            _, last_neo4j_record = self._exec_col_query(record['key'])
+            results.append(PopularTable(
+                database=last_neo4j_record['db']['name'],
+                cluster=last_neo4j_record['clstr']['name'],
+                schema=last_neo4j_record['schema']['name'],
+                name=last_neo4j_record['tbl']['name'],
+                description=self._safe_get(last_neo4j_record, 'tbl_dscrpt', 'description')))
         return {'table': results}
 
     @timer_with_counter
